import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  /* 首页 */
  {
    path: '/',
    component: Layout,
    redirect: '/home',
    hidden: true, // 隐藏
    children: [
      {
        path: 'home',
        name: 'Home',
        component: () => import('@/views/home/index'),
        meta: { title: '首页' }
      }
    ]
  },

  /* 服务器管理相关路由 */
  {
    path: '/server',
    component: Layout,
    redirect: '/server/server-list',
    name: 'Server',
    meta: { title: '服务器管理', icon: 'el-icon-s-help' },
    /* 服务器管理相关子路由 */
    children: [
      /* 服务器列表 */
      {
        path: 'server-list',
        name: 'ServerList',
        component: () => import('@/views/server/server-list/index'),
        meta: { title: '服务器列表' }
      },
      /* 服务器监控 */
      {
        path: 'server-monitor',
        name: 'ServerMonitor',
        component: () => import('@/views/server/server-monitor/index'),
        meta: { title: '服务器监控' }
      }
    ]
  },

  /* 项目管理相关路由 */
  {
    path: '/project',
    component: Layout,
    redirect: '/project/project-list',
    name: 'Project',
    meta: { title: '项目管理', icon: 'el-icon-s-help' },
    /* 项目管理相关子路由 */
    children: [
      /* 项目列表 */
      {
        path: 'project-list',
        name: 'ProjectList',
        component: () => import('@/views/project/project-list/index'),
        meta: { title: '项目列表' }
      },
      /* 项目部署 */
      {
        path: 'project-deploy',
        name: 'ProjectDeploy',
        component: () => import('@/views/project/project-deploy/index'),
        meta: { title: '项目部署' }
      },
      /* 项目监控 */
      {
        path: 'project-monitor',
        name: 'ProjectMonitor',
        component: () => import('@/views/project/project-monitor/index'),
        meta: { title: '项目监控' }
      },
      /* 异常监控 */
      {
        path: 'project-error-monitor',
        name: 'ProjectErrorMonitor',
        component: () => import('@/views/project/project-error-monitor/index'),
        meta: { title: '异常监控' }
      }
    ]
  },

  /* 员工管理相关路由 */
  {
    path: '/staff',
    component: Layout,
    redirect: '/staff/staff-list',
    name: 'Staff',
    alwaysShow: true,
    meta: { title: '员工管理', icon: 'el-icon-s-help' },
    /* 员工管理相关子路由 */
    children: [
      /* 员工列表 */
      {
        path: 'staff-list',
        name: 'StaffList',
        component: () => import('@/views/staff/staff-list/index'),
        meta: { title: '员工列表' }
      }
    ]
  },

  /* 系统设置相关路由 */
  {
    path: '/system',
    component: Layout,
    redirect: '/system/menu-settings',
    name: 'System',
    alwaysShow: true,
    meta: { title: '系统设置', icon: 'el-icon-s-help' },
    /* 系统设置相关子路由 */
    children: [
      /* 菜单设置 */
      {
        path: 'menu-settings',
        name: 'MenuSettings',
        component: () => import('@/views/system/menu-settings/index'),
        meta: { title: '菜单设置' }
      },
      /* 职位设置 */
      {
        path: 'job-settings',
        name: 'JobSettings',
        component: () => import('@/views/system/job-settings/index'),
        meta: { title: '职位设置' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
